@@ -2,8 +2,6 @@ stopifnot(require("testthat"),
           require("glmmTMB"),
           require("lme4"))
 
-context("offsets")
-
 set.seed(101)
 n <- 10000
 mux <- 10
@@ -58,7 +56,7 @@ test_that("LM with offset in formula - variable not in environment", {
 test_that("LM with offset in dispersion formula", {
     skip_on_cran()
     expect_equal(sigma(glmmTMB(y1~x, dat)),
-                 sigma(glmmTMB(y2~x,disp=~1+offset(log(o2)*2), dat)),
+                 sigma(glmmTMB(y2~x,disp=~1+offset(log(o2)), dat)),
                  tolerance=1e-3)
 
 })
@@ -66,7 +64,7 @@ test_that("LM with offset in dispersion formula", {
 test_that("LM with multiple offsets (cond/dispersion)", {
     skip_on_cran()
     m1 <<- glmmTMB(y0~x, dat)
-    m2 <<- glmmTMB(y3~x+offset(o),disp=~1+offset(log(o2)*2), dat)
+    m2 <<- glmmTMB(y3~x+offset(o),disp=~1+offset(log(o2)), dat)
     expect_equal(sigma(m1),sigma(m2),tolerance=1e-3)
     expect_equal(fixef(m1),fixef(m2),tolerance=1e-3)
 })
@@ -97,3 +95,12 @@ test_that("LONG offset in do.call", {
     m2 <- do.call(glmmTMB,list(Reaction ~ Days,ss,offset=off)) #breaks
     expect_equal(coef(m1),coef(m2))
 })
+
+# GH 773
+test_that("offset works with attributes", {
+  skip_on_cran()
+  dat$o <- drop(scale(dat$o))
+  m2 <- glmmTMB(y1~x + offset(o), data = dat)
+  expect_equal(unname(fixef(m2)$cond),
+               c(101.0121, 1.999318), tol = 1e-4)
+})
